@@ -6,7 +6,7 @@ from keyring import get_password, set_password
 from keyring.errors import KeyringError
 from requests import Response
 
-from pyinaturalist.constants import API_V0_BASE_URL, JWT_EXPIRATION, KEYRING_KEY
+from pyinaturalist.constants import API_V0, JWT_EXPIRATION, KEYRING_KEY
 from pyinaturalist.exceptions import AuthenticationError
 from pyinaturalist.session import ClientSession, get_local_session
 
@@ -92,7 +92,7 @@ def get_access_token(
             raise AuthenticationError('Not all authentication parameters were provided')
 
     # Get OAuth access token
-    response = session.post(f'{API_V0_BASE_URL}/oauth/token', json=payload)
+    response = session.post(f'{API_V0}/oauth/token', json=payload)
     response.raise_for_status()
     access_token = response.json()['access_token']
 
@@ -147,8 +147,9 @@ def _get_jwt(
     session: ClientSession, access_token: str = '', only_if_cached: bool = False
 ) -> Response:
     return session.get(
-        f'{API_V0_BASE_URL}/users/api_token',
+        f'{API_V0}/users/api_token',
         headers={'Authorization': f'Bearer {access_token}'},
         expire_after=JWT_EXPIRATION,  # type: ignore
         only_if_cached=only_if_cached,  # If True, will return a 504 if not cached
+        raise_for_status=False,
     )
