@@ -248,7 +248,7 @@ def test_message__str():
 def test_observation__converters():
     obs = Observation.from_json(j_observation_2)
     utc = tzoffset('Etc/UTC', 0)
-    assert obs.created_at == datetime(2020, 8, 27, 0, 0, tzinfo=utc)
+    assert obs.created_at == datetime(2020, 8, 27, 18, 0, 51, tzinfo=utc)
     assert obs.observed_on == datetime(2020, 8, 27, 8, 57, 22, tzinfo=utc)
 
     assert isinstance(obs.comments[0], Comment) and obs.comments[0].id == 5326888
@@ -598,6 +598,8 @@ def test_taxon__listed_taxa():
     listed_taxon = taxon.listed_taxa[0]
     assert isinstance(listed_taxon, ListedTaxon)
     assert listed_taxon.taxon_id == taxon.id
+    assert listed_taxon.list.id == 299
+    assert listed_taxon.list.title == 'United States Check List'
     assert taxon.listed_taxa_count == 4
     assert str(listed_taxon) == (
         'ListedTaxon(id=5577060, taxon_id=70118, place=Place(id=1, location=(0, 0), '
@@ -663,6 +665,18 @@ def test_taxon__update_from_full_record():
     pass
 
 
+def test_taxon_count__copy():
+    """When an IconPhoto is used in place of a missing Taxon.default_photo, and the taxon is copied
+    into a TaxonCount object, the IconPhoto object should be copied as-is instead of converting
+    back to a dict and then into a Photo.
+    """
+    taxon = Taxon(id=1, iconic_taxon_id=3)
+    taxon_counts = TaxonCount.copy(taxon)
+    assert isinstance(taxon.default_photo, IconPhoto)
+    assert isinstance(taxon_counts.default_photo, IconPhoto)
+    assert taxon.default_photo.medium_url == taxon_counts.default_photo.medium_url
+
+
 def test_taxon_counts__converters():
     taxon_counts = TaxonCounts.from_json(j_obs_species_counts)
     assert taxon_counts.data[0] == taxon_counts[0]
